<?php

/*

  Plugin Name: LoA Braintree

  Version: 1.0

  Plugin URI: https://legendsofaria.com/

  Author: Jacob Ralph

  Author URI: https://legendsofaria.com/

  Description: Subscription handling and payment integration with Braintree along with a management interface

 */

require 'core/db.php';
require 'core/utils.php';
require 'controllers/admin.php';
require 'controllers/sub.php';
require 'lib/braintree-php-3.39.0/lib/Braintree.php';

class Loa_Braintree {
    var $gateway;
    
    function __construct() {
        add_action('admin_menu', array($this, 'addMenu'));
        $this->gateway = new Braintree_Gateway([
            'environment' => 'sandbox',
            'merchantId' => 'r29zdhnfzv5hhwv9',
            'publicKey' => 'vpstk5w5dwnf5vhy',
            'privateKey' => '23bfc4e25431a2c1d5c1d8ac1f64aaee'
        ]);
    }

    function addMenu() {
        add_menu_page('Braintree', 'Braintree', 'administrator', 'braintree', array(&$this, 'loadPage'));
        add_submenu_page( 'braintree', 'Search Subscriptions', 'Search Subscriptions', 'administrator', 'braintree&action=list', array(&$this, 'loadPage'));
        add_submenu_page( 'braintree', 'Stats', 'Stats', 'administrator', 'braintree&action=stats', array(&$this, 'loadPage'));
    }

    function addShortCodes() {
        add_shortcode('braintree_sub', array(&$this, 'showSub'));
        add_shortcode('braintree_proc_sub', array(&$this, 'procSub'));
        add_shortcode('braintree_cancel_sub', array(&$this, 'cancelSub'));
    }

    function loadPage() {
        $this->addResources();
        if (!isset($_GET['action'])) {
            $_GET['action'] = "list";
        }
        $action = $_GET['action'];
        switch ($action) {
            case "list":
                $listCon = new adminController();
                $listCon->search_subs();
                break;
            case "search":
                $searchCon = new adminController();
                $searchCon->search_subs();
                break;
            case "cancel":
                $createCon = new adminController();
                $createCon->cancel_sub();
                break;
            case "stats":
                $createCon = new adminController();
                $createCon->stats();
                break;
            default:
                $listCon = new adminController();
                $listCon->search_subs();
                break;
        }
    }

    function showSub() {
        ob_start();
        $subCon = new subController($this->gateway);
        $subCon->show();
        return ob_get_clean();
    }

    function procSub() {
        ob_start();
        $ipnCon = new subController($this->gateway);
        $ipnCon->process();
        return ob_get_clean();
    }
    
    function cancelSub() {
        ob_start();
        $ipnCon = new subController($this->gateway);
        $ipnCon->cancel();
        return ob_get_clean();
    }

    function addResources() {
        //JQuery
        wp_enqueue_script('jquery', 'https://ajax.googleapis.com/ajax/libs/jquery/3.1.1/jquery.min.js', array(), null, true);

        // JS
        wp_register_script('prefix_bootstrap', '//maxcdn.bootstrapcdn.com/bootstrap/3.3.6/js/bootstrap.min.js');
        wp_enqueue_script('prefix_bootstrap');

        wp_enqueue_script('braintree_js', get_site_url() . '/wp-content/plugins/loa-braintree/lib/js/braintree-2.32.1.min.js');
        $this->enqueue_loa_styles();
    }

    function enqueue_loa_styles() {
        wp_register_style('prefix_bootstrap', '//maxcdn.bootstrapcdn.com/bootstrap/3.3.6/css/bootstrap.min.css');
        wp_enqueue_style('prefix_bootstrap');

        wp_register_style('loa_bt_custom', get_site_url() . '/wp-content/plugins/loa-braintree/lib/css/custom.css');
        wp_enqueue_style('loa_bt_custom');
    }

}

function validURI() {
    $uri = explode('/', $_SERVER['REQUEST_URI']);
    $valid_uris = ['', 'dashboard', 'subscribe', 'process-subscription', 'cancel-subscription'];
    if ($_SERVER['REQUEST_URI'] == '' || (count($uri) > 1 && in_array($uri[1], $valid_uris))) {
        return true;
    }

    return false;
}

$loa_bt = new Loa_Braintree();
$loa_bt->addShortCodes();
if (is_admin() && isset($_GET['page']) && $_GET['page'] === 'braintree') {
    add_action('loa_braintree_styles', array($loa_bt, 'enqueue_loa_styles'));
    do_action('loa_braintree_styles');
} else if (!is_admin() && validURI()) {
    wp_enqueue_script('jquery', 'https://ajax.googleapis.com/ajax/libs/jquery/3.1.1/jquery.min.js', array(), null, true);
    wp_enqueue_script('braintree_js', get_site_url() . '/wp-content/plugins/loa-braintree/lib/js/braintree-2.32.1.min.js');
    wp_register_style('loa_bt_custom', get_site_url() . '/wp-content/plugins/loa-braintree/lib/css/custom.css');
    wp_enqueue_style('loa_bt_custom');
}

function create_braintree_activation() {
    create_subscription_table_activation();
}

register_activation_hook(__FILE__, 'create_braintree_activation');

function create_subscription_table_activation() {
    global $wpdb;
    $table_name = 'wp_failed_subscription';
    if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
         //table not in database. Create new table
         $charset_collate = $wpdb->get_charset_collate();
     
         $sql = "CREATE TABLE $table_name (
                      id mediumint(9) NOT NULL AUTO_INCREMENT,
                      so_user_id varchar(256) NOT NULL,
                      data text NOT NULL,
                      UNIQUE KEY id (id)
                 ) $charset_collate;";
         require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
         dbDelta($sql);
    }
}
?>
